@@ -27,20 +27,20 @@ class PraatLoader:
                 f.write(self.scripts[s])
 
     def get_formants(self,filename,begin,end,nformants,ceiling):
-        output = self.runScript("formants-all.praat",[filename,begin,end,nformants,ceiling])
+        output = self.run_script("formants-all.praat",[filename,begin,end,nformants,ceiling])
         output = self.read_praat_out(output)
         return output
 
     def extract_token(self,filename,begin,end,outname):
-        out = self.runScript('extract.praat',[filename,begin,end,outname])
+        out = self.run_script('extract.praat',[filename,begin,end,outname])
 
     def spectro_pic(self,filename,formantCheck,nformants,ceiling,boundaries):
         numbounds = boundaries.count(',')
-        out = self.runScript('spectroPic.praat',[filename,formantCheck,nformants,ceiling,numbounds,boundaries])
+        out = self.run_script('spectroPic.praat',[filename,formantCheck,nformants,ceiling,numbounds,boundaries])
 
     def waveform_pic(self,filename,boundaries):
         numbounds = boundaries.count(',')
-        out = self.runScript('waveformPic.praat',[filename,numbounds,boundaries])
+        out = self.run_script('waveformPic.praat',[filename,numbounds,boundaries])
 
     def run_script(self,name,args):
         com = [self.praat, os.path.join(self.script_dir,name)] + map(str,args)
